@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: files9x.c 608 2004-04-17 10:55:44Z roms $ */
+/* $Id: files9x.c 778 2004-08-23 10:10:32Z roms $ */
 
 /*  libtifiles - Ti File Format library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -384,6 +384,13 @@ TIEXPORT int TICALL ti9x_read_flash_file(const char *filename,
     }
     fread(content->data_part, content->data_length, 1, f);
 
+    switch(content->data_part[0x05] >> 4)
+    {
+    case 2:	content->device_type = DEVICE_TYPE_89; break;	// TI89 or V200
+    case 4: content->device_type = DEVICE_TYPE_92P; break;	// TI92+
+    case 8: content->device_type = DEVICE_TYPE_89; break;   // TI89 Titanium
+    }
+
     content->next = NULL;
   } else {
     long file_size;
@@ -419,8 +426,13 @@ TIEXPORT int TICALL ti9x_read_flash_file(const char *filename,
       fread(content->data_part, content->data_length, 1, f);
 
       content->next = NULL;
+
       if (file_size == ftell(f))
-	break;
+          break;
+
+      // to be less restrictive with weird files
+      if((ftell(f) > file_size - 0x4e))
+	        break;
 
       content->next = (Ti9xFlash *) calloc(1, sizeof(Ti9xFlash));
       if (content->next == NULL) {
