@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: trans.c 578 2004-04-10 15:30:48Z roms $ */
+/* $Id: trans.c 791 2004-09-19 14:09:18Z roms $ */
 
 /*  libtifiles - Ti File Format library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -33,7 +33,7 @@
 #include <string.h>
 #include "stdints.h"
 
-#include "intl3.h"
+#include "gettext.h"
 #include "typesxx.h"
 #include "file_int.h"
 #include "macros.h"
@@ -335,11 +335,13 @@ TIEXPORT uint8_t TICALL *tixx_detokenize_varname(const char *varname,
   case CALC_TI82:
   case CALC_TI83:
   case CALC_TI83P:
+  case CALC_TI84P:
     return ti8x_detokenize_varname(varname, translate, vartype);
     break;
   case CALC_TI85:
   case CALC_TI86:
   case CALC_TI89:
+  case CALC_TI89T:
   case CALC_TI92:
   case CALC_TI92P:
   case CALC_V200:
@@ -830,17 +832,23 @@ TIEXPORT char* TICALL tifiles_transcode_to_ascii(char* dst, const char *src)
     {
     case CALC_TI73:
     case CALC_TI83:
-    case CALC_TI83P: f = transcode_from_ti83_charset_to_ascii; 
+    case CALC_TI83P: 
+	case CALC_TI84P: 
+		f = transcode_from_ti83_charset_to_ascii; 
       break;
-    case CALC_TI82:  f = transcode_from_ti82_charset_to_ascii; 
+    case CALC_TI82:  
+		f = transcode_from_ti82_charset_to_ascii; 
       break;
     case CALC_TI85:  
-    case CALC_TI86:  f = transcode_from_ti85_charset_to_ascii; 
+    case CALC_TI86:  
+		f = transcode_from_ti85_charset_to_ascii; 
       break;
     case CALC_TI89:
+    case CALC_TI89T:
     case CALC_TI92:
     case CALC_TI92P:
-    case CALC_V200:  f = transcode_from_ti9x_charset_to_ascii; 
+    case CALC_V200:  
+		f = transcode_from_ti9x_charset_to_ascii; 
       break;
 	default:
 		printl3(2, _("libtifiles error: unknown calc type. Program halted before crashing !\n"));
@@ -867,17 +875,23 @@ TIEXPORT char* TICALL tifiles_transcode_to_latin1(char* dst, const char *src)
     {
     case CALC_TI73:
     case CALC_TI83:
-    case CALC_TI83P: f = transcode_from_ti83_charset_to_latin1; 
+    case CALC_TI83P: 
+	case CALC_TI84P:
+		f = transcode_from_ti83_charset_to_latin1; 
       break;
-    case CALC_TI82:  f = transcode_from_ti82_charset_to_latin1; 
+    case CALC_TI82:  
+		f = transcode_from_ti82_charset_to_latin1; 
       break;
     case CALC_TI85:  
-    case CALC_TI86:  f = transcode_from_ti85_charset_to_latin1; 
+    case CALC_TI86:  
+		f = transcode_from_ti85_charset_to_latin1; 
       break;
     case CALC_TI89:
+    case CALC_TI89T:
     case CALC_TI92:
     case CALC_TI92P:
-    case CALC_V200:  f = transcode_from_ti9x_charset_to_latin1; 
+    case CALC_V200:  
+		f = transcode_from_ti9x_charset_to_latin1; 
       break;
 	default:
 	  printl3(2, "libtifiles error: unknown calc type. Program halted before crashing !\n");
@@ -907,17 +921,23 @@ TIEXPORT char* TICALL tifiles_transcode_to_utf8(char* dst, const char *src)
     {
     case CALC_TI73:
     case CALC_TI83:
-    case CALC_TI83P: f = transcode_from_ti83_charset_to_utf8; 
+    case CALC_TI83P: 
+	case CALC_TI84P: 
+		f = transcode_from_ti83_charset_to_utf8; 
       break;
-    case CALC_TI82:  f = transcode_from_ti82_charset_to_utf8; 
+    case CALC_TI82:  
+		f = transcode_from_ti82_charset_to_utf8; 
       break;
     case CALC_TI85:  
-    case CALC_TI86:  f = transcode_from_ti85_charset_to_utf8; 
+    case CALC_TI86:  
+		f = transcode_from_ti85_charset_to_utf8; 
       break;
     case CALC_TI89:
+	case CALC_TI89T:
     case CALC_TI92:
     case CALC_TI92P:
-    case CALC_V200:  f = transcode_from_ti9x_charset_to_utf8; 
+    case CALC_V200:  
+		f = transcode_from_ti9x_charset_to_utf8; 
       break;
 	default:
 	  printl3(2, "libtifiles error: unknown calc type. Program halted before crashing !\n");
@@ -930,7 +950,7 @@ TIEXPORT char* TICALL tifiles_transcode_to_utf8(char* dst, const char *src)
 
     // write our wide-char
     if ((uint16_t)wchar < 0x80)
-      *dst++ = wchar;
+      *dst++ = (char)wchar;
     else if ((uint16_t)wchar < 0x0800) {
       *dst++ = (0xC0 | (wchar >> 6)) & 0xff;
       *dst++ = (0x80 | (wchar & 0x3f)) & 0xff;
